// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLCOMMON_CONDVAR_H
#define XPLCOMMON_CONDVAR_H
//------------------------------------------------------------------------------

#if 0 // The public interface of a condition variable

//------------------------------------------------------------------------------

namespace xplcommon {

//------------------------------------------------------------------------------

class Mutex;

//------------------------------------------------------------------------------

/**
 * Condition variable.
 */
class CondVar
{
public:
    /**
     * Wait for the condition variable.
     *
     * @param mutex the mutex to unlock and re-lock.
     * @param timeout the number of milliseconds to wait at most. If
     * negative, the function will wait indefinitely.
     *
     * @return true, if the condition variable was signalled, false
     * if a timeout occured
     */
    bool wait(Mutex& mutex, int timeout = -1);

    /**
     * Signal the condition variable to wake up one thread.
     */
    void signal();

    /**
     * Signal all threads waiting on the condition variable.
     */
    void broadcast();
};

//------------------------------------------------------------------------------

} /* namespace xplcommon */

//------------------------------------------------------------------------------

#endif // 0, The public interface of a condition variable

//------------------------------------------------------------------------------

#include "config.h"

//------------------------------------------------------------------------------

#if TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "win32/CondVar.h"

namespace xplcommon { typedef win32::CondVar CondVar; }

//------------------------------------------------------------------------------

#else // TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "posix/CondVar.h"

namespace xplcommon { typedef posix::CondVar CondVar; }

//------------------------------------------------------------------------------

#endif // TARGET_API_WIN32

//------------------------------------------------------------------------------
#endif // XPLCOMMON_CONDVAR_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
